#
# spec file for package paraview
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major_ver 5.1
Name:           paraview
Version:        5.1.2
Release:        1.15
Summary:        Data analysis and visualization application
License:        BSD-3-Clause
Group:          Productivity/Scientific/Physics
Url:            http://www.paraview.org
Source0:        http://www.paraview.org/files/v%{major_ver}/ParaView-v%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE paraview-default-qtstyle.patch badshah400@gmail.com -- Make paraview inherit default qt gui look and feel, instead of using the Plastique theme
Patch0:         paraview-default-qtstyle.patch
# PATCH-FIX-UPSTREAM paraview-desktop-entry-fix.patch badshah400@gmail.com -- Fix desktop menu entry by inserting proper required categories
Patch1:         paraview-desktop-entry-fix.patch
# PATCH-FIX-UPSTREAM paraview-fix-file-contains-date-time.patch badshah400@gmail.com -- Remove reference to __DATE__ and __TIME__ from source
Patch2:         paraview-fix-file-contains-date-time.patch
Patch3:         require-only-cmake-3_0.patch
BuildRequires:  Mesa-devel
BuildRequires:  boost-devel
BuildRequires:  cmake >= 3.0
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  gnuplot
BuildRequires:  graphviz
BuildRequires:  libexpat-devel
BuildRequires:  libjpeg-devel
#BuildRequires:  libpq5
BuildRequires:  libQtWebKit-devel
BuildRequires:  libpqxx-devel
BuildRequires:  libqt4-devel >= 4.7.0
BuildRequires:  libtiff-devel
BuildRequires:  openssl-devel
BuildRequires:  python-devel
BuildRequires:  python-matplotlib
%py_requires
BuildRequires:  fdupes
BuildRequires:  python-twisted
BuildRequires:  python-zope.interface
BuildRequires:  qt4-assistant-adp-devel
BuildRequires:  readline-devel
BuildRequires:  tk-devel
BuildRequires:  wget
BuildRequires:  zlib-devel
Requires:       gnuplot
Requires:       graphviz
Requires:       python
Requires:       python-base
Requires:       python-twisted
Requires:       python-zope.interface
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
ParaView is an application designed with the need to visualize large data
sets in mind. The goals of the ParaView project include the following:

    * Develop an open-source, multi-platform visualization application.
    * Support distributed computation models to process large data sets.
    * Create an open, flexible, and intuitive user interface.
    * Develop an extensible architecture based on open standards.

ParaView runs on distributed and shared memory parallel as well as single
processor systems and has been successfully tested on Windows, Linux and
various Unix workstations and clusters. Under the hood, ParaView uses the
Visualization Toolkit as the data processing and rendering engine and has a
user interface written using a unique blend of Tcl/Tk and C++.

NOTE: The version in this package has NOT been compiled with MPI support.

# Split the SQTK plugin out into ints own package because it makes use of
# components with a different licence, viz., (L)GPL-3.0+ (bnc#804987).
%package -n %{name}-plugin-SciberQuestToolKit
Summary:        The SciberQuestToolKit plugin for paraview
License:        GPL-2.0+ or LGPL-3.0+
Group:          Productivity/Scientific/Physics
Requires:       paraview = %{version}-%{release}

%description -n %{name}-plugin-SciberQuestToolKit
ParaView is an application designed with the need to visualize large data
sets in mind. The goals of the ParaView project include the following:

    * Develop an open-source, multi-platform visualization application.
    * Support distributed computation models to process large data sets.
    * Create an open, flexible, and intuitive user interface.
    * Develop an extensible architecture based on open standards.

ParaView runs on distributed and shared memory parallel as well as single
processor systems and has been successfully tested on Windows, Linux and
various Unix workstations and clusters. Under the hood, ParaView uses the
Visualization Toolkit as the data processing and rendering engine and has a
user interface written using a unique blend of Tcl/Tk and C++.

This package provides the SciberQuestToolKit plugin for paraview.


%prep
%setup -q -n ParaView-v%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
# Prepare for gcc 4.9.0: work around gcc 4.9.0 regression
# https://gcc.gnu.org/bugzilla/show_bug.cgi?id=61294
sed -i -e 's/-Wl,--fatal-warnings//' VTK/CMake/vtkCompilerExtras.cmake

export CC='gcc'
export CXX='g++'
export MAKE='make'
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%define paraview_cmake_options \\\
        -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \\\
        -DVTK_INSTALL_INCLUDE_DIR:PATH=include/%{name} \\\
        -DVTK_INSTALL_ARCHIVE_DIR:PATH=%{_lib}/%{name} \\\
        -DVTK_INSTALL_LIBRARY_DIR:PATH=%{_lib}/%{name} \\\
        -DVTK_INSTALL_DATA_DIR=%{_datadir}/%{name} \\\
        -DBUILD_SHARED_LIBS:BOOL=ON \\\
        -DCMAKE_CXX_COMPILER:FILEPATH=$CXX \\\
        -DCMAKE_C_COMPILER:FILEPATH=$CC \\\
        -DCMAKE_BUILD_TYPE=RelWithDebInfo \\\
        -DPARAVIEW_BUILD_QT_GUI:BOOL=ON \\\
        -DPARAVIEW_QT_QMAKE_EXECUTABLE=%{_bindir}/qmake \\\
        -DPARAVIEW_BUILD_PLUGIN_SLACTools:BOOL=ON \\\
        -DPARAVIEW_ENABLE_PYTHON:BOOL=ON \\\
        -DVTK_WRAP_PYTHON:BOOL=ON \\\
        -DVTK_WRAP_PYTHON_SIP:BOOL=ON \\\
        -DVTK_OPENGL_HAS_OSMESA:BOOL=OFF \\\
        -DVTK_USE_SYSTEM_EXPAT:BOOL=ON \\\
        -DVTK_USE_SYSTEM_FREETYPE:BOOL=ON \\\
        -DVTK_USE_SYSTEM_JPEG:BOOL=ON \\\
        -DVTK_USE_SYSTEM_PNG:BOOL=ON \\\
        -DVTK_USE_SYSTEM_TIFF:BOOL=ON \\\
        -DVTK_USE_SYSTEM_ZLIB:BOOL=ON \\\
        -DVTK_USE_SYSTEM_ZOPE:BOOL=ON \\\
        -DVTK_USE_SYSTEM_TWISTED:BOOL=ON \\\
        -DBUILD_DOCUMENTATION:BOOL=ON \\\
        -DBUILD_EXAMPLES:BOOL=ON \\\
        -DBUILD_TESTING:BOOL=OFF

mkdir temp_dir
pushd temp_dir
cmake .. \
        -DPV_INSTALL_LIB_DIR:PATH=%{_lib}/%{name} \
        %{paraview_cmake_options}

make %{?_smp_mflags}
popd

%install
find . \( -name \*.txt -o -name \*.xml -o -name '*.[ch]' -o -name '*.[ch][px][px]' \) -print0 | xargs -0 chmod -x

pushd temp_dir
%makeinstall DESTDIR=%{buildroot}
popd
rm -rf temp_dir/

# FIX A BUNCH OF RPMLINT WARNINGS REGARDING python-bytecode-inconsistent-mtime
%py_compile %{buildroot}%{_libdir}/%{name}/site-packages/vtk/
for i in `ls -d %{buildroot}%{_libdir}/%{name}/site-packages/vtk/*/`;
do
  %py_compile $i/
done

%py_compile %{buildroot}%{_libdir}/%{name}/site-packages/paraview/vtk/util

# UNNECESSARY STATIC LIB
rm -fr %{buildroot}%{_libexecdir}/libFmmMesh.a

%fdupes %{buildroot}/

%post
/sbin/ldconfig
%icon_theme_cache_post
%desktop_database_post

%post -n %{name}-plugin-SciberQuestToolKit -p /sbin/ldconfig

%postun
/sbin/ldconfig
%icon_theme_cache_postun
%desktop_database_postun

%postun -n %{name}-plugin-SciberQuestToolKit -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc License_v1.2.txt
%{_libdir}/%{name}/
%{_bindir}/*
%{_datadir}/doc/%{name}-%{major_ver}/
%{_datadir}/%{name}/
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/cmake/hdf5/

%exclude %{_libdir}/%{name}/libSciberQuestToolKit.so

%files -n %{name}-plugin-SciberQuestToolKit
%defattr(-,root,root)
%doc Plugins/SciberQuestToolKit/eigen-3.0.3/eigen-eigen-3.0.3/COPYING.LGPL
%doc Plugins/SciberQuestToolKit/eigen-3.0.3/eigen-eigen-3.0.3/COPYING.GPL
%{_libdir}/%{name}/libSciberQuestToolKit.so

%changelog
* Fri Jul 29 2016 foss@grueninger.de
- update to version 5.1.2
  * Rendering translucent geometries: fixed client-server configurations
    when rendering remotely and resolved issues with multiple windows/views
    were present.
  * Exodus reader: Fixed bug in Exodus reader which was causing the reader to
    improperly read files with no timesteps.
  * Fixed the “?” button to show filter documentation.
  * Add option to Ghost Cells Generator filter to specify the number of ghost
    levels to generate.
  * Cinema Fixed SpecB was not revolving the camera around the data centroid.
- adjust require-only-cmake-3_0.patch
* Tue Jun 21 2016 foss@grueninger.de
- update to version 5.1.0
  + add OSPRay ray tracing renderer
  + interpolating point clouds
  + generic arrays
  + x-ray view
  + resampling to image
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=122
- adjust patch paraview-default-qtstyle.patch
- add require-only-cmake-3_0.patch to lower required CMake version
  to 3.0
* Wed Mar 30 2016 foss@grueninger.de
- update to version 5.0.1
  + Trace recorder fails for CTH data
  + improvements to cinema
  + Move Show Axis functionality into Edit Axes Grid
  + hover points on is deathly slow remote server
  + CGNS reader not available in non-MPI windows binaries
  + update pvospray
  + Keyboard shortcut Alt+A is assigned twice
  + Rubber band selection is broken
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=126
* Tue Mar 15 2016 dvaleev@suse.com
- Add disk constraint 8GB
* Mon Jan 11 2016 foss@grueninger.de
- Update to version 5.0.0
  + New Rendering Engine
  + OpenSWR and Mesa support
  + Include OSPray
  + Off-screen rendering with EGL
  + Community Atmosphere Model (Cam5) Catalyst Adaptor
  + Accelerated Algorithms plug-in
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=121
* Mon Sep 14 2015 badshah400@gmail.com
- Update to version 4.4.0:
  + List of changes at
    http://www.paraview.org/Bug/changelog_page.php?version_id=114.
- Drop paraview-freetype-2.5.4.patch: incorporated upstream.
* Sat Feb 14 2015 foss@grueninger.de
- Update to version 4.3.1:
  + See list of changes at
    http://www.paraview.org/Bug/changelog_page.php
- Packaging changes:
  + Install new file /usr/share/cmake/hdf5/libhdf5.settings
* Mon Jan  5 2015 dimstar@opensuse.org
- Add paraview-freetype-2.5.4.patch: Fix build with FreeType 2.5.4
  API changes.
* Wed Oct  1 2014 foss@grueninger.de
- Update to version 4.2.0:
  + See list of changes at
    http://vtk.org/Bug/changelog_page.php?version_id=108
- Packaging changes:
  + Drop paraview-Mesa10.3-build-failures.patch as this patch has
    been included upstream
* Mon Sep  8 2014 badshah400@gmail.com
- Update to version 4.2.0-RC1:
  + See list of changes at
    http://vtk.org/Bug/changelog_page.php?version_id=108
- Packaging changes:
  + Add paraview-desktop-entry-fix.patch to fix paraview's desktop
    menu entry by properly inserting required key-value pairs
  + Drop paraview-SciberQuestToolKit-install-path.patch; no longer
    needed as properly implemented upstream
  + Rebase carried-over patches to apply cleanly against present
    version
  + Add paraview-Mesa10.3-build-failures.patch to workaround
    build failures when compiling against Mesa >= 10.3; patch
    taken from upstream git and rebased; applied only for
    openSUSE >= 13.2
  + Specfile changes:
  - Prepare for gcc 4.9.0 by working around a compiler
    issue
  - Package .desktop entry and icon files; post(un) scriptlets
    for updating hicolor icon theme and updating desktop menu
    are used
  - Package appdata file
  - Fix python-bytecode-inconsistent-mtime rpmlint warnings by
    recompiling all relevant .py files.
* Tue Feb  4 2014 badshah400@gmail.com
- Build with system zope (python-zope.interface) and twisted
  (python-twisted); introduces BuildRequires and Requires on the
  two packages
- Remove unnecessary Requires on python-matplotlib.
* Sun Feb  2 2014 badshah400@gmail.com
- Update to version 4.1.0:
  + See list of changes at
    http://vtk.org/Bug/changelog_page.php?version_id=102
- Packaging changes:
  + Use full URL for source tarball
  + Drop patches:
  - paraview-fix-vtkpython-modules-install-dir.patch: corrected
    upstream
  - paraview-no-return-in-nonvoid-function.patch: corrected
    upstream
  + Rebase existing patches
  + Also fix a new occurrance of __DATE__ in a source file
    within paraview-fix-file-contains-date-time.patch
  + Change build type to RelWithDebInfo from Release
    (DCMAKE_BUILD_TYPE=RelWithDebInfo).
* Mon Jul  8 2013 badshah400@gmail.com
- Update to version 4.0.1:
  + Undocumented upstream changes
- Changes from version 4.0:
  + Too many to list, see
    http://paraview.org/Bug/changelog_page.php?version_id=52
    for a complete list
- Drop paraview-fix-build-with-system-jpeg.patch; implemented
  upstream
- Use matplotlib during building to enable MathText rendering;
  introduces build time and runtime requirement on
  python-matplotlib
- Add patches:
  + paraview-fix-vtkpython-modules-install-dir.patch: Workaround
    vtk's python modules getting installed in the wrong location;
    upstream bug report at
    http://paraview.org/Bug/view.php?id=14168
  + paraview-fix-file-contains-date-time.patch: Remove reference
    to __DATE__ and __TIME__ from source files
- Use fdupes to link duplicated files.
* Thu Jun 20 2013 badshah400@gmail.com
- Enable python scripting with paraview
  (cmake variable DPARAVIEW_ENABLE_PYTHON:BOOL=ON); had been
  turned off because earlier versions of paraview had some
  building issues with this enabled.
* Tue Mar 12 2013 badshah400@gmail.com
- Update to version 3.98.1:
  + See full list of changes at
    http://paraview.org/Bug/changelog_page.php?version_id=99.
- Add paraview-fix-build-with-system-jpeg.patch to fix build
  errors when compiled with recent jpeg headers (libjpeg8-devel >=
  8.0)
- Use smp flags for make to speed up build.
* Wed Feb 27 2013 badshah400@gmail.com
- License of SciberQuestToolKit subpackage is: GPL-2.0+ or
  LGPL-3.0+.
* Mon Feb 25 2013 badshah400@gmail.com
- Split the SciberQuestToolKit plugin into its own package,
  license it as GPL-3.0+ or LGPL-3.0+ (bnc#804987)
- The minimum version of libqt4-devel required for compiling is
  4.7.0; correct BuildRequires accordingly.
* Tue Jan 15 2013 badshah400@gmail.com
- Remove paraview-gcc47.patch; patch incorporated upstream.
* Tue Jan  8 2013 badshah400@gmail.com
- Update to version 3.98.0:
  + Too many changes to list, see
    http://paraview.org/Bug/changelog_page.php?version_id=97
  + Fixes licensing issues (bnc#763208)
- Remove paraview-boost-1.49-compat.patch, incorporated upstream
- Add paraview-no-return-in-nonvoid-function.patch to fix non-void
  function returning nothing
- Add paraview-SciberQuestToolKit-install-path.patch to fix
  install path of SciberQuestToolKit plugin
- Turn off OSMESA bindings because these are no longer
  recommended.
* Fri Oct 26 2012 badshah400@gmail.com
- Update to version 3.14.1:
  + Bug fix release, see a complete list at
    http://paraview.org/Bug/changelog_page.php?version_id=95 .
* Sat May 12 2012 scorot@free.fr
- fix SLE and 11.3 build with BuildRequires qt4-assistant-adp-devel
  for 11.4 and higher
* Sat Apr 28 2012 badshah400@gmail.com
- Added paraview-gcc47.patch to fix build failures with gcc >= 4.7:
  this fixes building on openSUSE > 12.1.
* Sun Apr  8 2012 badshah400@gmail.com
- Update to version 3.14.0:
  + Too many changes to list. See complete list at
    http://www.paraview.org/Bug/changelog_page.php?version_id=94
- Added paraview-boost-1.49-compat.patch to workaround vtk's
  incompatibility with boost version 1.48 and higher; fixes build
  on factory.
* Sun Nov  6 2011 badshah400@gmail.com
- Update to version 3.12.0:
  + Too many changes to list. See complete list at
    http://www.paraview.org/Bug/changelog_page.php?version_id=85
- Removed paraview-demo-patch. Changes committed upstream.
- Removed paraview-sqldatabaseschema.patch. Build failure
  properly taken care of upstream.
* Sun Apr  3 2011 badshah400@gmail.com
- Added paraview-default-qtstyle.patch to make paraview inherit
  user-set qt-GUI style instead of always using Plastique
* Sat Apr  2 2011 badshah400@gmail.com
- Added rpmlintrc file to suppress devel-file warnings for
  required files
* Thu Mar 31 2011 badshah400@gmail.com
- Initial package (version 3.10.0)
